package com.amazon.sample.iap.subscription;

import java.util.Arrays;
import java.util.List;

/**
 *
 * MySku enum contains all In App Purchase products definition that the sample
 * app will use. The product definition includes two properties: "SKU" and
 * "Available Marketplace".
 *
 */
public enum MySku {

    //The only subscription product used in this sample app
    MY_MAGAZINE_SUBS("com.amazon.sample.iap.subscription.mymagazine", Arrays.asList("AU", "BR", "CA", "CN", "DE", "ES", "FR", "GB", "IN", "IT",
            "JP", "MX", "US"));

    private final String sku;
    private final List<String> availableMarketplaces;

    /**
     * Returns the Sku string of the MySku object
     * @return
     */
    public String getSku() {
        return this.sku;
    }

    /**
     * Returns the Available Marketplace of the MySku object
     * @return
     */
    public List<String> getAvailableMarketplaces() {
        return this.availableMarketplaces;
    }

    private MySku(final String sku, final List<String> availableMarketplaces) {
        this.sku = sku;
        this.availableMarketplaces = availableMarketplaces;
    }

    /**
     * Returns the MySku object from the specified Sku and marketplace value.
     * @param sku
     * @param marketplace
     * @return
     */
    public static MySku fromSku(final String sku, final String marketplace) {
        if (MY_MAGAZINE_SUBS.getSku().equals(sku) && (null == marketplace || MY_MAGAZINE_SUBS.getAvailableMarketplaces()
                .contains(marketplace.toUpperCase()))) {
            return MY_MAGAZINE_SUBS;
        }
        return null;
    }

}
